@@ -1,30 +1,26 @@
 #! /bin/false
 
 # vim: tabstop=4
-# $Id: _Aliases.pm,v 1.8 2003/08/07 10:38:59 guido Exp $
+# $Id: _Aliases.pm,v 1.9 2003/09/10 17:03:33 guido Exp $
 
 # Internally known aliases for charsets.
 # Copyright (C) 2002-2003 Guido Flohr <guido@imperia.net>,
 # all rights reserved.
 
-# Distribution either under the terms of the Artistic license (see
-# Artistic) or - at your choice - under the terms and conditions of
-# the GNU General Public License described below.
-
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2, or (at your option)
+# This program is free software; you can redistribute it and/or modify it
+# under the terms of the GNU Library General Public License as published
+# by the Free Software Foundation; either version 2, or (at your option)
 # any later version.
-
+                                                                                
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-# 02111-1307, USA.
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+# Library General Public License for more details.
+                                                                                
+# You should have received a copy of the GNU Library General Public 
+# License along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, 
+# USA.
 
 package Locale::Recode::_Aliases;
 
@@ -695,7 +691,7 @@ __END__
 
 =head1 NAME
 
-Locale::Recode::_Aliases
+Locale::Recode::_Aliases - Internal Charset Alias Database for libintl-perl
 
 =head1 SYNOPSIS
 
@@ -731,7 +727,7 @@ Copyright (C) 2002-2003, Guido Flohr E<lt>guido@imperia.netE<gt>, all
 rights reserved.  See the source code for details.
 
 This software is contributed to the Perl community by Imperia 
-(http://www.imperia.net/).
+(L<http://www.imperia.net/>).
 
 =head1 SEE ALSO
 
